overlay_transient

Function overlay_transient 

pub fn overlay_transient(
    base: impl AsFd,
    mode: Option<Mode>,
    mount_attr_flags: Option<MountAttrFlags>,
) -> Result<()>
Mounts a transient overlayfs with passed in fd as the lowerdir.

The tmpfs used for the overlay upper layer inherits the SELinux label from the base filesystem to prevent label mismatches (see #1992).